==> ydoc-4.0.6.tgz: package/README-en.md <==
<p align="center">
  <a href="https://ydoc.ymfe.org/">
    <img src="https://ws1.sinaimg.cn/large/006FkmqZly1fpswv9gzalj305e05ft98.jpg" width="194" alt="logo" srcSet="https://ws1.sinaimg.cn/large/006FkmqZly1fpswvk5qsyj30as0au75x.jpg 2x" />
  </a>
</p>

## YDoc

![npm (tag)](https://img.shields.io/npm/v/ydoc.svg)
![npm (tag)](https://img.shields.io/npm/v/ydoc/rc.svg)
![npm](https://img.shields.io/npm/dm/localeval.svg)
![license](https://img.shields.io/github/license/YMFE/ydoc.svg)

YDoc is an elegant document station construction tool that can easily generate complete static sites based on markdown, allowing you to focus on document writing.

YDoc has a flexible and powerful plugin/theme mechanism that allows developers to easily customize their own documentation site.

We use `🐶` as our LOGO. Dogs are good friends of human beings, and they are nimble and agile: YDoc is such a tool.

[Homepage](https://ydoc.ymfe.org/) | [中文 README](https://github.com/YMFE/ydoc/blob/master/README.md)

## Usage

#### install
```
npm install -g ydoc
```

### install the rc version (Release Candidate)
```
npm install ydoc@rc [-g]
```

#### build
```
ydoc init
ydoc build
```

## Plugins

- [ydoc-plugin-copy](https://www.npmjs.com/package/ydoc-plugin-copy): Quickly copy the code snippet of the markdown generated page。
- [ydoc-plugin-import-asset](https://www.npmjs.com/package/ydoc-plugin-import-asset): Import js/css files in the page.
- [ydoc-plugin-jsdoc](https://www.npmjs.com/package/ydoc-plugin-jsdoc): Generate documents based on code comments, developed by 'jsdoc'
- [ydoc-plugin-pangu](https://www.npmjs.com/package/ydoc-plugin-pangu): 
Automatically insert space between all Chinese characters and half-size English, numbers, and symbols in your page.
- [more... ](https://ydoc.ymfe.org/plugin/index.html)

## Developers

- [dwb1994](https://github.com/dwb1994) (dev & design)
- [sean1025](https://github.com/hellosean1025) (dev)
- [zwjamnsss](https://github.com/amnsss) (dev & design)

We welcome all of you to participate in our development, you may submit [pull requests](https://github.com/YMFE/ydoc/pulls) to help us improve the program, we alse glad to see you help developing [plugins](https://ydoc.ymfe.org/plugin/index.html).

At the same time, we also welcome everyone's valuable comments or suggestions on YDoc: [github issues](https://github.com/YMFE/ydoc/issues)

==> ydoc-4.1.2.tgz: package/README-en.md <==
<p align="center">
  <a href="https://hellosean1025.github.io/ydoc/">
    <img src="https://ws1.sinaimg.cn/large/006FkmqZly1fpswv9gzalj305e05ft98.jpg" width="194" alt="logo" srcSet="https://ws1.sinaimg.cn/large/006FkmqZly1fpswvk5qsyj30as0au75x.jpg 2x" />
  </a>
</p>

## YDoc

![npm (tag)](https://img.shields.io/npm/v/ydoc.svg)
![npm (tag)](https://img.shields.io/npm/v/ydoc/rc.svg)
![npm](https://img.shields.io/npm/dm/localeval.svg)
![license](https://img.shields.io/github/license/YMFE/ydoc.svg)

YDoc is an elegant document station construction tool that can easily generate complete static sites based on markdown, allowing you to focus on document writing.

YDoc has a flexible and powerful plugin/theme mechanism that allows developers to easily customize their own documentation site.

We use `🐶` as our LOGO. Dogs are good friends of human beings, and they are nimble and agile: YDoc is such a tool.

[Homepage](https://hellosean1025.github.io/ydoc/) | [中文 README](https://github.com/YMFE/ydoc/blob/master/README.md)

## Usage

#### install
```
npm install -g ydoc
```

### install the rc version (Release Candidate)
```
npm install ydoc@rc [-g]
```

#### build
```
ydoc init
ydoc build
```

## Plugins

- [ydoc-plugin-copy](https://www.npmjs.com/package/ydoc-plugin-copy): Quickly copy the code snippet of the markdown generated page。
- [ydoc-plugin-import-asset](https://www.npmjs.com/package/ydoc-plugin-import-asset): Import js/css files in the page.
- [ydoc-plugin-jsdoc](https://www.npmjs.com/package/ydoc-plugin-jsdoc): Generate documents based on code comments, developed by 'jsdoc'
- [ydoc-plugin-pangu](https://www.npmjs.com/package/ydoc-plugin-pangu): 
Automatically insert space between all Chinese characters and half-size English, numbers, and symbols in your page.
- [more... ](https://hellosean1025.github.io/ydoc/plugin/index.html)

## Themes

- [ydoc-theme-demo](https://www.npmjs.com/package/ydoc-theme-demo)
- [ydoc-theme-dark](https://www.npmjs.com/package/ydoc-theme-dark)

## Developers

- [dwb1994](https://github.com/dwb1994) (dev & design)
- [lwg529](https://github.com/lwg529) (dev)
- [sean1025](https://github.com/hellosean1025) (dev)
- [zwjamnsss](https://github.com/amnsss) (dev & design)

We welcome all of you to participate in our development, you may submit [pull requests](https://github.com/YMFE/ydoc/pulls) to help us improve the program, we alse glad to see you help developing [plugins](https://hellosean1025.github.io/ydoc/plugin/index.html).

At the same time, we also welcome everyone's valuable comments or suggestions on YDoc: [github issues](https://github.com/YMFE/ydoc/issues)
